.. -*- mode: rst -*-

cppyy: Python-C++ bindings interface based on Cling/LLVM
========================================================

cppyy provides fully automatic, dynamic Python-C++ bindings by leveraging
the Cling C++ interpreter and LLVM.
It supports both PyPy (natively), CPython, and C++11/14/17.

Details and performance are described in
`this paper <http://cern.ch/wlav/Cppyy_LavrijsenDutta_PyHPC16.pdf>`_,
but note that the CPython performance has been vastly improved since
that conference.

Full documentation: `cppyy.readthedocs.io <http://cppyy.readthedocs.io/>`_.

Notebook-based tutorial: `Cppyy Tutorial <https://bitbucket.org/wlav/cppyy/src/master/doc/tutorial/CppyyTutorial.ipynb?viewer=nbviewer&fileviewer=notebook-viewer%3Anbviewer>`_.
